==> alone-frame-3.2.6.tgz: package/route/setVue.js <==
import {dir_name} from "../tool/nodes.js";

import {sync as globSync} from "glob";

import nodes from "../tool/nodes.js";

import alone from "../tool/alone.js";

import {fileURLToPath} from "url";

//获取view列表
const view_file = function (view_path, exclude = {}, route = "{", i = 0) {
    globSync(view_path + '/**/*.vue').forEach((file) => {
        let status = true;
        const path = alone.trim(file.replace(/\\/g, '/').replace(/\.vue$/, '').replace(view_path, ''), '/');
        if (alone.isset(exclude)) {
            const arr = path.split('/');
            const dir_list = exclude.dir || [];
            const dir_name = arr.length > 1 ? arr.slice(0, -1).join('/') : "";
            if (alone.isset(dir_list) && alone.isset(dir_name)) {
                if (dir_list.includes(dir_name)) {
                    status = false;
                }
            }
            if (status === true) {
                const file_list = exclude.file || [];
                if (alone.isset(file_list)) {
                    if (file_list.includes(path)) {
                        status = false;
                    }
                }
            }
        }
        if (status === true) {
            ++i;
            route += `\r\n        "${path}": () => import(\`${view_path}/${path}.vue\`),`;
        }
    });
    return (i > 0 ? alone.trim(route, ',') + "\r\n    }" : "{}");
};

export const delView = function () {
    const node = nodes(dir_name(fileURLToPath(import.meta.url)));
    node.save_file(`vueList.js`, `export default {\r\n    list: {},\r\n    time: "${alone.get_time()}"\r\n}`);
}

//设置view目录,排除文件或者目录(文件不用输入格式),run是否根目录
export const setView = function (view_dir, {dir = [], file = [], run = false} = {}) {
    const node = nodes(dir_name(fileURLToPath(import.meta.url)));
    const view_path = run === false ? alone.rtrim(process.cwd(), '/') + "/" + alone.trim(view_dir, '/') : view_dir;
    const json = view_file(view_path.replace(/\\/g, '/'), {dir, file});
    node.save_file(`vueList.js`, `export default {\r\n    list: ${json},\r\n    time: "${alone.get_time()}"\r\n}`);
    return json;
}

export const setVuePlugins = function (view_dir, {dir = [], file = [], run = false} = {}) {
    return {
        name: 'alone-route',
        buildStart() {
            setView(view_dir, {dir: dir, file: file, run: run});
        }
    }
}

export default setView

==> alone-frame-3.2.7.tgz: package/route/setVue.js <==
import {dir_name} from "../tool/nodes.js";

import {sync as globSync} from "glob";

import nodes from "../tool/nodes.js";

import alone from "../tool/alone.js";

import {fileURLToPath} from "url";

//获取view列表
const view_file = function (view_path, exclude = {}, route = "{", i = 0) {
    globSync(view_path + '/**/*.vue').forEach((file) => {
        let status = true;
        const path = alone.trim(file.replace(/\\/g, '/').replace(/\.vue$/, '').replace(view_path, ''), '/');
        if (alone.isset(exclude)) {
            const arr = path.split('/');
            const dir_list = exclude.dir || [];
            const dir_name = arr.length > 1 ? arr.slice(0, -1).join('/') : "";
            if (alone.isset(dir_list) && alone.isset(dir_name)) {
                if (dir_list.includes(dir_name)) {
                    status = false;
                }
            }
            if (status === true) {
                const file_list = exclude.file || [];
                if (alone.isset(file_list)) {
                    if (file_list.includes(path)) {
                        status = false;
                    }
                }
            }
        }
        if (status === true) {
            ++i;
            route += `\r\n        "${path}": () => import(\`${view_path}/${path}.vue\`),`;
        }
    });
    return (i > 0 ? alone.trim(route, ',') + "\r\n    }" : "{}");
};

export const delView = function () {
    const node = nodes(dir_name(fileURLToPath(import.meta.url)));
    node.save_file(`vueList.js`, `export default {}`);
}

//设置view目录,排除文件或者目录(文件不用输入格式),run是否根目录
export const setView = function (view_dir, {dir = [], file = [], run = false} = {}) {
    const node = nodes(dir_name(fileURLToPath(import.meta.url)));
    const view_path = run === false ? alone.rtrim(process.cwd(), '/') + "/" + alone.trim(view_dir, '/') : view_dir;
    const json = view_file(view_path.replace(/\\/g, '/'), {dir, file});
    node.save_file(`vueList.js`, `export default ${json}`);
    return json;
}

export const setVuePlugins = function (view_dir, {dir = [], file = [], run = false} = {}) {
    return {
        name: 'alone-route',
        buildStart() {
            setView(view_dir, {dir: dir, file: file, run: run});
        }
    }
}

export default setView
